pub struct MemoryCache { /* private fields */ }Expand description
Thread-safe in-memory discovery cache.
Implementations
Sourceimpl MemoryCache
impl MemoryCache
Sourcepub fn new(options: CacheOptions) -> Self
pub fn new(options: CacheOptions) -> Self
Create a new memory cache with the given options.
If mode is CacheMode::Disabled, get always returns None and put is a no-op.