absolute

Function absolute 

pub fn absolute(path: impl AsRef<Path>) -> Result<PathBuf, PathError>
Make path absolute.

  • Absolute inputs are lexically normalized.
  • Relative inputs are joined with the process current directory, then normalized.

Filesystem access

Reads the current working directory for relative inputs. Does not require the path to exist and does not resolve symlinks.