resolve_against

Function resolve_against 

pub fn resolve_against(
    base: impl AsRef<Path>,
    input: impl AsRef<Path>,
) -> Result<PathBuf, PathError>
Resolve input against base.

  • If input is absolute, it is normalized and returned (base is ignored).
  • If input is relative, it is joined to base and normalized.

Filesystem access

No (unless base itself requires later I/O by the caller). Does not follow symlinks. Does not require existence.