Optional discovery caching.
Caching is opt-in and must never be used as a security boundary. Stale entries are performance artifacts, not authoritative filesystem state.
Structs
- Cache
Key - Cache key capturing all inputs that affect discovery results.
- Cache
Options - Configuration for a discovery cache instance.
- Cache
Value - Cached discovery result.
- Memory
Cache - Thread-safe in-memory discovery cache.
- Persistent
Cache persistent-cache - Persistent on-disk cache (feature
persistent-cache).
Enums
- Cache
Mode - Cache storage mode.
- Cache
Policy - Whether / how a search should consult the cache.
Traits
- Discovery
Cache - Trait for discovery result caches.