MemoryCache

Struct MemoryCache 

pub struct MemoryCache { /* private fields */ }
Thread-safe in-memory discovery cache.

Implementations

Source

impl MemoryCache

pub fn new(options: CacheOptions) -> Self

Create a new memory cache with the given options.

If mode is CacheMode::Disabled, get always returns None and put is a no-op.

pub fn len(&self) -> Result<usize, PathError>

Number of entries currently stored (for tests).

pub fn is_empty(&self) -> Result<bool, PathError>

Returns true if the cache is empty.